@@ -11,7 +11,7 @@ use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_SAML;
 our @ISA = qw(Lemonldap::NG::Portal::_SAML);
 
-our $VERSION = '1.9.5';
+our $VERSION = '1.9.7';
 
 ## @method void issuerDBInit()
 # Load and check SAML configuration
@@ -1272,6 +1272,18 @@ sub issuerForAuthUser {
                     );
                     return PE_SAML_SSO_ERROR;
                 }
+
+                # Force NameID Format
+                my $nameIDFormatKey =
+                  $self->{samlSPMetaDataOptions}->{$idp_initiated_spConfKey}
+                  ->{samlSPMetaDataOptionsNameIDFormat} || "email";
+                eval {
+                    $login->request()->NameIDPolicy()
+                      ->Format( $self->getNameIDFormat($nameIDFormatKey) );
+                };
+
+                # Force AllowCreate to TRUE
+                eval { $login->request()->NameIDPolicy()->AllowCreate(1); };
             }
 
             # Process authentication request
